<?php

/**
 * UCMM WPBrigade Settings
 *
 * @since 1.0.0
 */
if ( !class_exists( 'UCMM_WPBrigade_Setting' ) ) :

class UCMM_WPBrigade_Setting {

    private $settings_api;

    function __construct() {

      include_once( UCMM_WPBRIGADE_ROOT_PATH . '/classes/ucmm-wpbrigade-settings-api.php' );
      $this->settings_api = new UCMM_WPBrigade_Settings_API;

      add_action( 'admin_init', array( $this, 'ucmm_wpbrigade_setting_init' ) );
      add_action( 'admin_menu', array( $this, 'ucmm_wpbrigade_setting_menu' ) );
    }

    function ucmm_wpbrigade_setting_init() {

        //set the settings
        $this->settings_api->set_sections( $this->get_ucmm_settings_sections() );
        $this->settings_api->set_fields( $this->get_ucmm_settings_fields() );

        //initialize settings
        $this->settings_api->admin_init();
    }

    function ucmm_wpbrigade_setting_menu() {

      add_menu_page( __( 'Under Construction', 'ucmm-wpbrigade' ), __( 'Under Construction', 'ucmm-wpbrigade' ), 'manage_options', "ucmm_settings", '__return_null', '', 50 );

      add_submenu_page( 'ucmm_settings', __( 'Settings', 'ucmm-wpbrigade' ), __( 'Settings', 'ucmm-wpbrigade' ), 'manage_options', "ucmm_settings", array( $this, 'plugin_page' ) );

      add_submenu_page( 'ucmm_settings', __( 'Customizer', 'ucmm-wpbrigade' ), __( 'Customizer', 'ucmm-wpbrigade' ), 'manage_options', "under-construction-maintenance-mode", '__return_null' );

    }

    function get_ucmm_settings_sections() {
        $sections = array(
            array(
                'id'    => 'ucmm_wpbrigade_setting',
                'title' => __( 'Settings', 'ucmm-wpbrigade' ),
                'desc'  => sprintf( __( 'Under Construction page is customizable through %1$sWordPress Customizer%2$s.', 'ucmm-wpbrigade' ), '<a href="' . admin_url( 'admin.php?page=under-construction-maintenance-mode' ) . '">', '</a>' ),
            ),
            // array(
            //     'id'    => 'ucmm_wpbrigade_mc_lists',
            //     'title' => __( 'MailChimp', 'ucmm-wpbrigade' ),
            //     'desc'  => __( 'MailChimp Lists', 'ucmm-wpbrigade' ),
            // ),
            // array(
            //     'id'    => 'ucmm_wpbrigade_seo',
            //     'title' => __( 'SEO Configuration', 'ucmm-wpbrigade' ),
            //     'desc'  => __( 'SEO Configuration', 'ucmm-wpbrigade' ),
            // ),
            // array(
            //     'id'    => 'ucmm_wpbrigade_premium',
            //     'title' => __( 'Try Primum Veriosn', 'ucmm-wpbrigade' )
            // )
        );
        return $sections;
    }

    /**
     * Returns all the settings fields
     *
     * @return array settings fields
     */
    function get_ucmm_settings_fields() {

      global $wp_roles;
      $ucmm_wpbrigade_roles = array();
      foreach( $wp_roles->roles as $role => $val ) {

        $ucmm_wpbrigade_roles['ucmm-wpbrigade_role_'.$role] = $val['name'];
      }

      $settings_fields = array(
        'ucmm_wpbrigade_setting' => array(
            array(
                'name'  => 'ucmm-status',
                'label' => __( 'Activate:', 'ucmm-wpbrigade' ),
                'desc'  => __( 'Check the field to activate the maintenance mode.', 'ucmm-wpbrigade' ),
                'type'  => 'checkbox'
            ),
            array(
              'name'                => 'ucmm-enable',
              'label'               => __( 'Disable Roles:', 'ucmm-wpbrigade' ),
              'desc'                => __( 'Choose the roles to disable under construction mode on that', 'ucmm-wpbrigade' ),
              'type'                => 'multicheck',
              // 'default'             => array( 'ucmm-wpbrigade_role_administrator' => 'Administrator'),
              'options'             => $ucmm_wpbrigade_roles
            ),
          ),
        // 'ucmm_wpbrigade_seo' => array(
        //   array(
        //       'name'              => 'ucmm-seo-locale',
        //       'label'             => __( 'SEO Locale', 'ucmm-wpbrigade' ),
        //       'desc'              => __( 'Text input description', 'ucmm-wpbrigade' ),
        //       'placeholder'       => get_bloginfo('language'),
        //       'type'              => 'text',
        //       'sanitize_callback' => 'sanitize_text_field'
        //   ),
        //   array(
        //       'name'              => 'ucmm-seo-type',
        //       'label'             => __( 'SEO Type', 'ucmm-wpbrigade' ),
        //       'desc'              => __( 'Text input description', 'ucmm-wpbrigade' ),
        //       'placeholder'       => __( 'website', 'ucmm-wpbrigade' ),
        //       'type'              => 'text',
        //       'sanitize_callback' => 'sanitize_text_field'
        //   ),
        //   array(
        //       'name'              => 'ucmm-seo-title',
        //       'label'             => __( 'SEO Title', 'ucmm-wpbrigade' ),
        //       'desc'              => __( 'Text input description', 'ucmm-wpbrigade' ),
        //       'placeholder'       => get_bloginfo('name'),
        //       'type'              => 'text',
        //       'sanitize_callback' => 'sanitize_text_field'
        //   ),
        //   array(
        //       'name'              => 'ucmm-seo-desc',
        //       'label'             => __( 'SEO Description', 'ucmm-wpbrigade' ),
        //       'desc'              => __( 'Text input description', 'ucmm-wpbrigade' ),
        //       'placeholder'       => __( 'Text Input placeholder', 'ucmm-wpbrigade' ),
        //       'type'              => 'text',
        //       'sanitize_callback' => 'sanitize_text_field'
        //   ),
        //   array(
        //       'name'              => 'ucmm-seo-url',
        //       'label'             => __( 'SEO URL', 'ucmm-wpbrigade' ),
        //       'desc'              => __( 'Text input description', 'ucmm-wpbrigade' ),
        //       'placeholder'       => get_bloginfo('url'),
        //       'type'              => 'text',
        //       'sanitize_callback' => 'sanitize_text_field'
        //   ),
        //   array(
        //       'name'              => 'ucmm-seo-site-name',
        //       'label'             => __( 'SEO Site Name', 'ucmm-wpbrigade' ),
        //       'desc'              => __( 'Text input description', 'ucmm-wpbrigade' ),
        //       'placeholder'       => get_bloginfo('name'),
        //       'type'              => 'text',
        //       'sanitize_callback' => 'sanitize_text_field'
        //   ),
        //   array(
        //       'name'              => 'ucmm-seo-keyword',
        //       'label'             => __( 'SEO Keyword', 'ucmm-wpbrigade' ),
        //       'desc'              => __( 'Text input description', 'ucmm-wpbrigade' ),
        //       'placeholder'       => __( 'Text Input placeholder', 'ucmm-wpbrigade' ),
        //       'type'              => 'text',
        //       'sanitize_callback' => 'sanitize_text_field'
        //   ),
        // ),
        // 'ucmm_wpbrigade_mc_lists' => array(
        //   array(
        //     'name'  => 'ucmm-mc-api-key',
        //     'label' => __( 'API Key:', 'ucmm-wpbrigade' ),
        //     'desc'  => __( 'Mail Chimp Key.', 'ucmm-wpbrigade' ),
        //     'type'  => 'text'
        //   ),
        //   array(
        //     'name'    => 'selectbox',
        //     'label'   => __( 'Lists', 'ucmm-wpbrigade' ),
        //     'desc'    => __( 'Select the List', 'ucmm-wpbrigade' ),
        //     'type'    => 'select',
        //     'default' => 'no',
        //     'options' => array(
        //         // 'yes' => '55555555555555555',
        //         // 'no'  => '66666666666666666'
        //     )
        //   ),
        // ),
      );

      return $settings_fields;
    }

    function plugin_page() {
        echo '<div class="wrap ucmm-wpbrigade">';
        echo '<h2>' . __( 'Under Construction: Settings', 'ucmm-wpbrigade' ) . '</h2><br />';
        $this->settings_api->show_navigation();
        $this->settings_api->show_forms();

        echo '</div>';
    }

    /**
     * Get all the pages
     *
     * @return array page names with key value pairs
     */
    function get_pages() {
        $pages = get_pages();
        $pages_options = array();
        if ( $pages ) {
            foreach ($pages as $page) {
                $pages_options[$page->ID] = $page->post_title;
            }
        }

        return $pages_options;
    }

}
endif;
